import unittest
from plone.app.openid.tests.base import OpenIdTestCase
from Products.PluggableAuthService.interfaces.plugins \
        import IExtractionPlugin, ILoginPasswordExtractionPlugin

class TestOpenIdView(OpenIdTestCase):
    def test_DefaultConfig(self):
        pas_info=self.pas_info
        self.assertEquals(pas_info.hasOpenIDdExtractor(), False)
        self.assertEquals(pas_info.hasLoginPasswordExtractor(), True)

    def test_OpenIdInstalled(self):
        self.portal.portal_quickinstaller.installProduct("plone.app.openid")
        pas_info=self.pas_info
        self.assertEquals(pas_info.hasOpenIDdExtractor(), True)
        self.assertEquals(pas_info.hasLoginPasswordExtractor(), True)

    def testOnlyOpenIdInstalled(self):
        plugins=self.pas.plugins.listPlugins(IExtractionPlugin)
        for (id, plugin) in plugins:
            if ILoginPasswordExtractionPlugin.providedBy(plugin):
                plugin.manage_activateInterfaces(interfaces=())
        self.portal.portal_quickinstaller.installProduct("plone.app.openid")

        pas_info=self.pas_info
        self.assertEquals(pas_info.hasOpenIDdExtractor(), True)
        self.assertEquals(pas_info.hasLoginPasswordExtractor(), False)


def test_suite():
    suite=unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestOpenIdView))
    return suite




from setuptools import setup, find_packages
import os

version = '1.0.2'

setup(name='plone.app.openid',
      version=version,
      description="Plone OpenID authentication support",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      classifiers=[
        "Framework :: Plone",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='Plone OpenID authentication consumer',
      author='Wichert AkkermanPlone Foundation',
      author_email='plone-developers@lists.sourceforge.net',
      url='http://svn.plone.org/svn/plone/plone.app.openid',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages = ['plone', 'plone.app'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        'plone.openid',
        'setuptools',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



from OFS.Application import install_package
import plone.openid
from Products.PloneTestCase import PloneTestCase
PloneTestCase.setupPloneSite()

class OpenIdTestCase(PloneTestCase.PloneTestCase):
    def afterSetUp(self):
        # Since Zope 2.10.4 we need to install our package manually
        install_package(self.app, plone.openid, plone.openid.initialize)

    @property
    def pas(self):
        return self.portal.acl_users

    @property
    def pas_info(self):
        return self.pas.restrictedTraverse("@@pas_info")


class OpenIdFunctionalTestCase(PloneTestCase.Functional, OpenIdTestCase):
    pass
